Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Message) predicate.Message
- func ChannelEQ(v Channel) predicate.Message
- func ChannelIn(vs ...Channel) predicate.Message
- func ChannelNEQ(v Channel) predicate.Message
- func ChannelNotIn(vs ...Channel) predicate.Message
- func ChannelValidator(c Channel) error
- func Content(v string) predicate.Message
- func ContentContains(v string) predicate.Message
- func ContentContainsFold(v string) predicate.Message
- func ContentEQ(v string) predicate.Message
- func ContentEqualFold(v string) predicate.Message
- func ContentGT(v string) predicate.Message
- func ContentGTE(v string) predicate.Message
- func ContentHasPrefix(v string) predicate.Message
- func ContentHasSuffix(v string) predicate.Message
- func ContentIn(vs ...string) predicate.Message
- func ContentLT(v string) predicate.Message
- func ContentLTE(v string) predicate.Message
- func ContentNEQ(v string) predicate.Message
- func ContentNotIn(vs ...string) predicate.Message
- func CreatedAt(v time.Time) predicate.Message
- func CreatedAtEQ(v time.Time) predicate.Message
- func CreatedAtGT(v time.Time) predicate.Message
- func CreatedAtGTE(v time.Time) predicate.Message
- func CreatedAtIn(vs ...time.Time) predicate.Message
- func CreatedAtLT(v time.Time) predicate.Message
- func CreatedAtLTE(v time.Time) predicate.Message
- func CreatedAtNEQ(v time.Time) predicate.Message
- func CreatedAtNotIn(vs ...time.Time) predicate.Message
- func HasAttachments() predicate.Message
- func HasAttachmentsWith(preds ...predicate.Attachment) predicate.Message
- func HasReactions() predicate.Message
- func HasReactionsWith(preds ...predicate.Reaction) predicate.Message
- func ID(id uuid.UUID) predicate.Message
- func IDEQ(id uuid.UUID) predicate.Message
- func IDGT(id uuid.UUID) predicate.Message
- func IDGTE(id uuid.UUID) predicate.Message
- func IDIn(ids ...uuid.UUID) predicate.Message
- func IDLT(id uuid.UUID) predicate.Message
- func IDLTE(id uuid.UUID) predicate.Message
- func IDNEQ(id uuid.UUID) predicate.Message
- func IDNotIn(ids ...uuid.UUID) predicate.Message
- func MessageTypeEQ(v MessageType) predicate.Message
- func MessageTypeIn(vs ...MessageType) predicate.Message
- func MessageTypeNEQ(v MessageType) predicate.Message
- func MessageTypeNotIn(vs ...MessageType) predicate.Message
- func MessageTypeValidator(mt MessageType) error
- func Not(p predicate.Message) predicate.Message
- func Or(predicates ...predicate.Message) predicate.Message
- func Recipient(v string) predicate.Message
- func RecipientContains(v string) predicate.Message
- func RecipientContainsFold(v string) predicate.Message
- func RecipientEQ(v string) predicate.Message
- func RecipientEqualFold(v string) predicate.Message
- func RecipientGT(v string) predicate.Message
- func RecipientGTE(v string) predicate.Message
- func RecipientHasPrefix(v string) predicate.Message
- func RecipientHasSuffix(v string) predicate.Message
- func RecipientIn(vs ...string) predicate.Message
- func RecipientLT(v string) predicate.Message
- func RecipientLTE(v string) predicate.Message
- func RecipientNEQ(v string) predicate.Message
- func RecipientNotIn(vs ...string) predicate.Message
- func ReplyToID(v uuid.UUID) predicate.Message
- func ReplyToIDEQ(v uuid.UUID) predicate.Message
- func ReplyToIDGT(v uuid.UUID) predicate.Message
- func ReplyToIDGTE(v uuid.UUID) predicate.Message
- func ReplyToIDIn(vs ...uuid.UUID) predicate.Message
- func ReplyToIDIsNil() predicate.Message
- func ReplyToIDLT(v uuid.UUID) predicate.Message
- func ReplyToIDLTE(v uuid.UUID) predicate.Message
- func ReplyToIDNEQ(v uuid.UUID) predicate.Message
- func ReplyToIDNotIn(vs ...uuid.UUID) predicate.Message
- func ReplyToIDNotNil() predicate.Message
- func Runtime(v string) predicate.Message
- func RuntimeContains(v string) predicate.Message
- func RuntimeContainsFold(v string) predicate.Message
- func RuntimeEQ(v string) predicate.Message
- func RuntimeEqualFold(v string) predicate.Message
- func RuntimeGT(v string) predicate.Message
- func RuntimeGTE(v string) predicate.Message
- func RuntimeHasPrefix(v string) predicate.Message
- func RuntimeHasSuffix(v string) predicate.Message
- func RuntimeIn(vs ...string) predicate.Message
- func RuntimeIsNil() predicate.Message
- func RuntimeLT(v string) predicate.Message
- func RuntimeLTE(v string) predicate.Message
- func RuntimeNEQ(v string) predicate.Message
- func RuntimeNotIn(vs ...string) predicate.Message
- func RuntimeNotNil() predicate.Message
- func Sender(v string) predicate.Message
- func SenderContains(v string) predicate.Message
- func SenderContainsFold(v string) predicate.Message
- func SenderEQ(v string) predicate.Message
- func SenderEqualFold(v string) predicate.Message
- func SenderGT(v string) predicate.Message
- func SenderGTE(v string) predicate.Message
- func SenderHasPrefix(v string) predicate.Message
- func SenderHasSuffix(v string) predicate.Message
- func SenderIn(vs ...string) predicate.Message
- func SenderLT(v string) predicate.Message
- func SenderLTE(v string) predicate.Message
- func SenderNEQ(v string) predicate.Message
- func SenderNotIn(vs ...string) predicate.Message
- func Team(v string) predicate.Message
- func TeamContains(v string) predicate.Message
- func TeamContainsFold(v string) predicate.Message
- func TeamEQ(v string) predicate.Message
- func TeamEqualFold(v string) predicate.Message
- func TeamGT(v string) predicate.Message
- func TeamGTE(v string) predicate.Message
- func TeamHasPrefix(v string) predicate.Message
- func TeamHasSuffix(v string) predicate.Message
- func TeamIn(vs ...string) predicate.Message
- func TeamLT(v string) predicate.Message
- func TeamLTE(v string) predicate.Message
- func TeamNEQ(v string) predicate.Message
- func TeamNotIn(vs ...string) predicate.Message
- func ValidColumn(column string) bool
- type Channel
- type MessageType
- type OrderOption
- func ByAttachments(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByAttachmentsCount(opts ...sql.OrderTermOption) OrderOption
- func ByChannel(opts ...sql.OrderTermOption) OrderOption
- func ByContent(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByMessageType(opts ...sql.OrderTermOption) OrderOption
- func ByReactions(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByReactionsCount(opts ...sql.OrderTermOption) OrderOption
- func ByRecipient(opts ...sql.OrderTermOption) OrderOption
- func ByReplyToID(opts ...sql.OrderTermOption) OrderOption
- func ByRuntime(opts ...sql.OrderTermOption) OrderOption
- func BySender(opts ...sql.OrderTermOption) OrderOption
- func ByTeam(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the message type in the database. Label = "message" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldSender holds the string denoting the sender field in the database. FieldSender = "sender" // FieldRecipient holds the string denoting the recipient field in the database. FieldRecipient = "recipient" // FieldContent holds the string denoting the content field in the database. FieldContent = "content" // FieldMessageType holds the string denoting the message_type field in the database. FieldMessageType = "message_type" // FieldTeam holds the string denoting the team field in the database. FieldTeam = "team" // FieldChannel holds the string denoting the channel field in the database. FieldChannel = "channel" // FieldRuntime holds the string denoting the runtime field in the database. FieldRuntime = "runtime" // FieldReplyToID holds the string denoting the reply_to_id field in the database. FieldReplyToID = "reply_to_id" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // EdgeAttachments holds the string denoting the attachments edge name in mutations. EdgeAttachments = "attachments" // EdgeReactions holds the string denoting the reactions edge name in mutations. EdgeReactions = "reactions" // Table holds the table name of the message in the database. Table = "messages" // AttachmentsTable is the table that holds the attachments relation/edge. AttachmentsTable = "attachments" // AttachmentsInverseTable is the table name for the Attachment entity. // It exists in this package in order to avoid circular dependency with the "attachment" package. AttachmentsInverseTable = "attachments" // AttachmentsColumn is the table column denoting the attachments relation/edge. AttachmentsColumn = "message_attachments" // ReactionsTable is the table that holds the reactions relation/edge. ReactionsTable = "reactions" // ReactionsInverseTable is the table name for the Reaction entity. // It exists in this package in order to avoid circular dependency with the "reaction" package. ReactionsInverseTable = "reactions" // ReactionsColumn is the table column denoting the reactions relation/edge. ReactionsColumn = "message_reactions" )
const DefaultMessageType = MessageTypeText
MessageTypeText is the default value of the MessageType enum.
Variables ¶
var ( // SenderValidator is a validator for the "sender" field. It is called by the builders before save. SenderValidator func(string) error // RecipientValidator is a validator for the "recipient" field. It is called by the builders before save. RecipientValidator func(string) error // TeamValidator is a validator for the "team" field. It is called by the builders before save. TeamValidator func(string) error // RuntimeValidator is a validator for the "runtime" field. It is called by the builders before save. RuntimeValidator func(string) error // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultID holds the default value on creation for the "id" field. DefaultID func() uuid.UUID )
var Columns = []string{ FieldID, FieldSender, FieldRecipient, FieldContent, FieldMessageType, FieldTeam, FieldChannel, FieldRuntime, FieldReplyToID, FieldCreatedAt, }
Columns holds all SQL columns for message fields.
Functions ¶
func ChannelNEQ ¶
ChannelNEQ applies the NEQ predicate on the "channel" field.
func ChannelNotIn ¶
ChannelNotIn applies the NotIn predicate on the "channel" field.
func ChannelValidator ¶
ChannelValidator is a validator for the "channel" field enum values. It is called by the builders before save.
func Content ¶
Content applies equality check predicate on the "content" field. It's identical to ContentEQ.
func ContentContains ¶
ContentContains applies the Contains predicate on the "content" field.
func ContentContainsFold ¶
ContentContainsFold applies the ContainsFold predicate on the "content" field.
func ContentEqualFold ¶
ContentEqualFold applies the EqualFold predicate on the "content" field.
func ContentGTE ¶
ContentGTE applies the GTE predicate on the "content" field.
func ContentHasPrefix ¶
ContentHasPrefix applies the HasPrefix predicate on the "content" field.
func ContentHasSuffix ¶
ContentHasSuffix applies the HasSuffix predicate on the "content" field.
func ContentLTE ¶
ContentLTE applies the LTE predicate on the "content" field.
func ContentNEQ ¶
ContentNEQ applies the NEQ predicate on the "content" field.
func ContentNotIn ¶
ContentNotIn applies the NotIn predicate on the "content" field.
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func HasAttachments ¶
HasAttachments applies the HasEdge predicate on the "attachments" edge.
func HasAttachmentsWith ¶
func HasAttachmentsWith(preds ...predicate.Attachment) predicate.Message
HasAttachmentsWith applies the HasEdge predicate on the "attachments" edge with a given conditions (other predicates).
func HasReactions ¶
HasReactions applies the HasEdge predicate on the "reactions" edge.
func HasReactionsWith ¶
HasReactionsWith applies the HasEdge predicate on the "reactions" edge with a given conditions (other predicates).
func MessageTypeEQ ¶
func MessageTypeEQ(v MessageType) predicate.Message
MessageTypeEQ applies the EQ predicate on the "message_type" field.
func MessageTypeIn ¶
func MessageTypeIn(vs ...MessageType) predicate.Message
MessageTypeIn applies the In predicate on the "message_type" field.
func MessageTypeNEQ ¶
func MessageTypeNEQ(v MessageType) predicate.Message
MessageTypeNEQ applies the NEQ predicate on the "message_type" field.
func MessageTypeNotIn ¶
func MessageTypeNotIn(vs ...MessageType) predicate.Message
MessageTypeNotIn applies the NotIn predicate on the "message_type" field.
func MessageTypeValidator ¶
func MessageTypeValidator(mt MessageType) error
MessageTypeValidator is a validator for the "message_type" field enum values. It is called by the builders before save.
func Recipient ¶
Recipient applies equality check predicate on the "recipient" field. It's identical to RecipientEQ.
func RecipientContains ¶
RecipientContains applies the Contains predicate on the "recipient" field.
func RecipientContainsFold ¶
RecipientContainsFold applies the ContainsFold predicate on the "recipient" field.
func RecipientEQ ¶
RecipientEQ applies the EQ predicate on the "recipient" field.
func RecipientEqualFold ¶
RecipientEqualFold applies the EqualFold predicate on the "recipient" field.
func RecipientGT ¶
RecipientGT applies the GT predicate on the "recipient" field.
func RecipientGTE ¶
RecipientGTE applies the GTE predicate on the "recipient" field.
func RecipientHasPrefix ¶
RecipientHasPrefix applies the HasPrefix predicate on the "recipient" field.
func RecipientHasSuffix ¶
RecipientHasSuffix applies the HasSuffix predicate on the "recipient" field.
func RecipientIn ¶
RecipientIn applies the In predicate on the "recipient" field.
func RecipientLT ¶
RecipientLT applies the LT predicate on the "recipient" field.
func RecipientLTE ¶
RecipientLTE applies the LTE predicate on the "recipient" field.
func RecipientNEQ ¶
RecipientNEQ applies the NEQ predicate on the "recipient" field.
func RecipientNotIn ¶
RecipientNotIn applies the NotIn predicate on the "recipient" field.
func ReplyToID ¶
ReplyToID applies equality check predicate on the "reply_to_id" field. It's identical to ReplyToIDEQ.
func ReplyToIDEQ ¶
ReplyToIDEQ applies the EQ predicate on the "reply_to_id" field.
func ReplyToIDGT ¶
ReplyToIDGT applies the GT predicate on the "reply_to_id" field.
func ReplyToIDGTE ¶
ReplyToIDGTE applies the GTE predicate on the "reply_to_id" field.
func ReplyToIDIn ¶
ReplyToIDIn applies the In predicate on the "reply_to_id" field.
func ReplyToIDIsNil ¶
ReplyToIDIsNil applies the IsNil predicate on the "reply_to_id" field.
func ReplyToIDLT ¶
ReplyToIDLT applies the LT predicate on the "reply_to_id" field.
func ReplyToIDLTE ¶
ReplyToIDLTE applies the LTE predicate on the "reply_to_id" field.
func ReplyToIDNEQ ¶
ReplyToIDNEQ applies the NEQ predicate on the "reply_to_id" field.
func ReplyToIDNotIn ¶
ReplyToIDNotIn applies the NotIn predicate on the "reply_to_id" field.
func ReplyToIDNotNil ¶
ReplyToIDNotNil applies the NotNil predicate on the "reply_to_id" field.
func Runtime ¶
Runtime applies equality check predicate on the "runtime" field. It's identical to RuntimeEQ.
func RuntimeContains ¶
RuntimeContains applies the Contains predicate on the "runtime" field.
func RuntimeContainsFold ¶
RuntimeContainsFold applies the ContainsFold predicate on the "runtime" field.
func RuntimeEqualFold ¶
RuntimeEqualFold applies the EqualFold predicate on the "runtime" field.
func RuntimeGTE ¶
RuntimeGTE applies the GTE predicate on the "runtime" field.
func RuntimeHasPrefix ¶
RuntimeHasPrefix applies the HasPrefix predicate on the "runtime" field.
func RuntimeHasSuffix ¶
RuntimeHasSuffix applies the HasSuffix predicate on the "runtime" field.
func RuntimeIsNil ¶
RuntimeIsNil applies the IsNil predicate on the "runtime" field.
func RuntimeLTE ¶
RuntimeLTE applies the LTE predicate on the "runtime" field.
func RuntimeNEQ ¶
RuntimeNEQ applies the NEQ predicate on the "runtime" field.
func RuntimeNotIn ¶
RuntimeNotIn applies the NotIn predicate on the "runtime" field.
func RuntimeNotNil ¶
RuntimeNotNil applies the NotNil predicate on the "runtime" field.
func Sender ¶
Sender applies equality check predicate on the "sender" field. It's identical to SenderEQ.
func SenderContains ¶
SenderContains applies the Contains predicate on the "sender" field.
func SenderContainsFold ¶
SenderContainsFold applies the ContainsFold predicate on the "sender" field.
func SenderEqualFold ¶
SenderEqualFold applies the EqualFold predicate on the "sender" field.
func SenderHasPrefix ¶
SenderHasPrefix applies the HasPrefix predicate on the "sender" field.
func SenderHasSuffix ¶
SenderHasSuffix applies the HasSuffix predicate on the "sender" field.
func SenderNotIn ¶
SenderNotIn applies the NotIn predicate on the "sender" field.
func TeamContains ¶
TeamContains applies the Contains predicate on the "team" field.
func TeamContainsFold ¶
TeamContainsFold applies the ContainsFold predicate on the "team" field.
func TeamEqualFold ¶
TeamEqualFold applies the EqualFold predicate on the "team" field.
func TeamHasPrefix ¶
TeamHasPrefix applies the HasPrefix predicate on the "team" field.
func TeamHasSuffix ¶
TeamHasSuffix applies the HasSuffix predicate on the "team" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type Channel ¶
type Channel string
Channel defines the type for the "channel" enum field.
type MessageType ¶
type MessageType string
MessageType defines the type for the "message_type" enum field.
const ( MessageTypeText MessageType = "text" MessageTypeSystem MessageType = "system" MessageTypeNotification MessageType = "notification" )
MessageType values.
func (MessageType) String ¶
func (mt MessageType) String() string
type OrderOption ¶
OrderOption defines the ordering options for the Message queries.
func ByAttachments ¶
func ByAttachments(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByAttachments orders the results by attachments terms.
func ByAttachmentsCount ¶
func ByAttachmentsCount(opts ...sql.OrderTermOption) OrderOption
ByAttachmentsCount orders the results by attachments count.
func ByChannel ¶
func ByChannel(opts ...sql.OrderTermOption) OrderOption
ByChannel orders the results by the channel field.
func ByContent ¶
func ByContent(opts ...sql.OrderTermOption) OrderOption
ByContent orders the results by the content field.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByMessageType ¶
func ByMessageType(opts ...sql.OrderTermOption) OrderOption
ByMessageType orders the results by the message_type field.
func ByReactions ¶
func ByReactions(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByReactions orders the results by reactions terms.
func ByReactionsCount ¶
func ByReactionsCount(opts ...sql.OrderTermOption) OrderOption
ByReactionsCount orders the results by reactions count.
func ByRecipient ¶
func ByRecipient(opts ...sql.OrderTermOption) OrderOption
ByRecipient orders the results by the recipient field.
func ByReplyToID ¶
func ByReplyToID(opts ...sql.OrderTermOption) OrderOption
ByReplyToID orders the results by the reply_to_id field.
func ByRuntime ¶
func ByRuntime(opts ...sql.OrderTermOption) OrderOption
ByRuntime orders the results by the runtime field.
func BySender ¶
func BySender(opts ...sql.OrderTermOption) OrderOption
BySender orders the results by the sender field.
func ByTeam ¶
func ByTeam(opts ...sql.OrderTermOption) OrderOption
ByTeam orders the results by the team field.